@@ -933,6 +933,7 @@ class cloud:
         if noLines == False:
             GammaSum += rates['GammaDustLine']
             GammaSumMax = max(GammaSumMax, rates['GammaDustLine'])
+        lumScale = rates['maxAbsdEdtDust']
 
         # Step 3: if we don't have an initial guess, make one by
         # assuming that dust-gas coupling is negligible, and that the
@@ -943,12 +944,22 @@ class cloud:
                      (c*a*self.dust.sigma10*0.1**self.dust.beta)) ** \
                      (1.0/(4.0+self.dust.beta))
 
-        # Step 4: solve for T_d using Newton's method
-        self.Td = newton(_dustTempResid, self.Td, \
-                             maxiter=200, \
-                             args=(self, PsiUser, \
-                                       GammaSum, GammaSumMax, \
-                                       verbose))
+        # Step 4: get initial scaling
+        rates = cloud.dEdt(dustOnly=True, sumOnly=True, \
+                               PsiUser=PsiUser, \
+                               fixedLevPop=True, \
+                               verbose=verbose)
+        lumScale = rates['maxAbsdEdtDust']
+
+        # Step 5: solve for T_d using Newton's method
+        try:
+            self.Td = newton(_dustTempResid, self.Td, \
+                                 maxiter=200, \
+                                 args=(self, PsiUser, \
+                                           GammaSum, GammaSumMax, \
+                                           lumScale, verbose))
+        except (despoticError, RuntimeError):
+            pass
 
         # Check that we're really converged; if not, try again
         # starting from guessed starting position
@@ -958,11 +969,15 @@ class cloud:
                 (GammaSum / \
                      (c*a*self.dust.sigma10*0.1**self.dust.beta)) ** \
                      (1.0/(4.0+self.dust.beta))
-            self.Td = newton(_dustTempResid, self.Td, \
-                                 maxiter=200, \
-                                 args=(self, PsiUser, \
-                                           GammaSum, GammaSumMax, \
-                                           verbose))
+            try:
+                self.Td = newton(_dustTempResid, self.Td, \
+                                     maxiter=200, \
+                                     args=(self, PsiUser, \
+                                               GammaSum, GammaSumMax, \
+                                               lumScale, verbose))
+            except (despoticError, RuntimeError):
+                # If we're here, we failed to converge
+                return False
 
         # Test for success and return appropriate value
         if abs(_dustTempResid(self.Td, self, PsiUser, GammaSum, \
@@ -1033,17 +1048,29 @@ class cloud:
             if self.Tg==0.0:
                 self.Tg = 10.0
 
+        # Get initial scaling
+        rates = self.dEdt(c1Grav=c1Grav, \
+                               thin=thin, LTE=LTE, \
+                               escapeProbGeom=escapeProbGeom, \
+                               gasOnly=True, noClump=noClump, \
+                               sumOnly=True, PsiUser=PsiUser)
+        lumScale = rates['maxAbsdEdtGas']
+
         # Solve for Tg
-        self.Tg = newton(_gasTempResid, self.Tg, \
-                             args=(self, c1Grav, \
-                                       thin, LTE, \
-                                       escapeProbGeom, PsiUser, \
-                                       noClump, verbose))
+        try:
+            self.Tg = newton(_gasTempResid, self.Tg, \
+                                 args=(self, c1Grav, \
+                                           thin, LTE, \
+                                           escapeProbGeom, PsiUser, \
+                                           noClump, lumScale, verbose))
+        except (despoticError, RuntimeError):
+            # If we're here, we failed to converge
+            return False
 
         # Check for success and return appropriate value
         if abs(_gasTempResid(self.Tg, self, c1Grav, thin, LTE, \
                                  escapeProbGeom, PsiUser, \
-                                 noClump, verbose)) > 1.0e-3:
+                                 noClump, lumScale, verbose)) > 1.0e-3:
             return False
         else:
             return True
@@ -1112,11 +1139,22 @@ class cloud:
                 self.Td = 10.0
         Tinit = np.array([self.Tg, self.Td])
 
+        # Get luminosity scaling
+        rates = cloud.dEdt(c1Grav=c1Grav, thin=thin, LTE=LTE, \
+                               escapeProbGeom=escapeProbGeom, \
+                               sumOnly=True, PsiUser=PsiUser, \
+                               noClump=noClump, \
+                               verbose=verbose)
+        lumScale = zeros(2)
+        lumScale[0] = rates['maxAbsdEdtGas']
+        lumScale[1] = rates['maxAbsdEdtDust']
+
         # Iterate to get equilibrium temperatures
         res = root(_gdTempResid, Tinit, \
                            args=(self, c1Grav, thin, \
                                      LTE, escapeProbGeom, \
-                                     PsiUser, noClump, verbose), \
+                                     PsiUser, noClump, lumScale, \
+                                     verbose), \
                        method='hybr', options = { 'xtol' : tol })
 
         # Make sure we've converged.
@@ -1674,7 +1712,8 @@ class cloud:
 #    noClump -- Boolean; if true, clumping factors are turned off
 ########################################################################
 def _gdTempResid(Tgd, cloud, c1Grav, thin, LTE, \
-                    escapeProbGeom, PsiUser, noClump, verbose):
+                     escapeProbGeom, PsiUser, noClump, lumScale, \
+                     verbose):
 
     # Insert current dust and gas temperatures into cloud structure;
     # floor to CMB temperature to prevent numerical badness in case
@@ -1696,15 +1735,20 @@ def _gdTempResid(Tgd, cloud, c1Grav, thin, LTE, \
 
     # Print status
     if verbose:
+        #print "setTempEq: dE_gas/dt = " + str(rates['dEdtGas']) + \
+        #    " erg s^-1 H^-1, dE_dust/dt = " + \
+        #    str(rates['dEdtDust']) + " erg s^-1 H^-1, " + \
+        #    "residuals = " + str(rates['dEdtGas']/rates['maxAbsdEdtGas']) + \
+        #    " " + str(rates['dEdtDust']/rates['maxAbsdEdtDust'])
         print "setTempEq: dE_gas/dt = " + str(rates['dEdtGas']) + \
             " erg s^-1 H^-1, dE_dust/dt = " + \
             str(rates['dEdtDust']) + " erg s^-1 H^-1, " + \
-            "residuals = " + str(rates['dEdtGas']/rates['maxAbsdEdtGas']) + \
-            " " + str(rates['dEdtDust']/rates['maxAbsdEdtDust'])
+            "residuals = " + str(rates['dEdtGas']/lumScale[0]) + \
+            " " + str(rates['dEdtDust']/lumScale[1])
 
     # Return result
     return np.array([rates['dEdtGas'], rates['dEdtDust']]) \
-        / np.array([rates['maxAbsdEdtGas'], rates['maxAbsdEdtDust']])
+        / lumScale
 
 
 ########################################################################
@@ -1720,7 +1764,8 @@ def _gdTempResid(Tgd, cloud, c1Grav, thin, LTE, \
 #        that go into GammaSum, needed for normalization
 #    verbose -- verbose or not
 ########################################################################
-def _dustTempResid(Td, cloud, PsiUser, GammaSum, GammaSumMax, verbose):
+def _dustTempResid(Td, cloud, PsiUser, GammaSum, GammaSumMax, lumScale, \
+                       verbose):
 
     # Insert current dust temperature into gas structure, with a floor
     # equal to the CMB floor to prevent numerical problems if the
@@ -1739,12 +1784,10 @@ def _dustTempResid(Td, cloud, PsiUser, GammaSum, GammaSumMax, verbose):
         print "_dustTempResid called with Td = "+str(cloud.Td) + \
             ", dEdt = " + str(GammaSum+rates['dEdtDust']) + \
             ", residual = " + \
-            str((GammaSum+rates['dEdtDust'])/ \
-                    max(GammaSumMax, rates['maxAbsdEdtDust']))
+            str((GammaSum+rates['dEdtDust'])/lumScale)
 
     # Return dE/dt with correct normalization
-    return (GammaSum+rates['dEdtDust'])/ \
-        max(GammaSumMax, rates['maxAbsdEdtDust'])
+    return (GammaSum+rates['dEdtDust'])/lumScale
 
 
 ########################################################################
@@ -1765,7 +1808,8 @@ def _dustTempResid(Td, cloud, PsiUser, GammaSum, GammaSumMax, verbose):
 #    verbose -- verbose or not
 ########################################################################
 def _gasTempResid(Tg, cloud, c1Grav, thin, LTE, \
-                     escapeProbGeom, PsiUser, noClump, verbose):
+                      escapeProbGeom, PsiUser, noClump, lumScale, \
+                      verbose):
 
     # Insert current dust temperature into gas structure, using CMB
     # temperature as a floor
@@ -1780,14 +1824,18 @@ def _gasTempResid(Tg, cloud, c1Grav, thin, LTE, \
 
     # If verbose, print status
     if verbose:
+        #print "_gasTempResid called with Tg = "+str(cloud.Tg) + \
+        #    ", dEdt = " + str(rates['dEdtGas']) + \
+        #    ", residual = " + \
+        #    str(rates['dEdtGas']/rates['maxAbsdEdtGas'])
         print "_gasTempResid called with Tg = "+str(cloud.Tg) + \
             ", dEdt = " + str(rates['dEdtGas']) + \
             ", residual = " + \
-            str(rates['dEdtGas']/rates['maxAbsdEdtGas'])
-
+            str(rates['dEdtGas']/lumScale)
 
     # Return dE/dt with correct normalization
-    return rates['dEdtGas']/rates['maxAbsdEdtGas']
+    #return rates['dEdtGas']/rates['maxAbsdEdtGas']
+    return rates['dEdtGas']/lumScale
 
 
 ########################################################################
